@@ -1,39 +1,41 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import os
 import sys
 import gettext
 import time
 import threading
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
 import gi
 gi.require_version("Gtk", "3.0")
-gi.require_version("AppIndicator3", "0.1")
-from gi.repository import Gtk, Gdk, GLib
-from gi.repository import AppIndicator3 as AppIndicator
+gi.require_version("XApp", "1.0")
+from gi.repository import Gtk, Gdk, GLib, XApp
 from mintupload_core import *
 
 # i18n
 gettext.install("mintupload", "/usr/share/linuxmint/locale")
 
 # Name of the icon used by the indicator
-SYSTRAY_ICON = "mintupload-tray"
+SYSTRAY_ICON = "mintupload-tray-symbolic"
 
 class MainClass:
 
     def __init__(self):
         self.drop_zones = {}
-        self.status_icon = AppIndicator.Indicator.new("mintupload", _("Upload services"), AppIndicator.IndicatorCategory.APPLICATION_STATUS)
-        self.status_icon.set_status(AppIndicator.IndicatorStatus.ACTIVE)
-        self.status_icon.set_icon(SYSTRAY_ICON)
-        self.status_icon.set_title(_("Upload services"))
         self.services = None
 
         self.build_services_menu()
         # Refresh list of services in the menu every 2 seconds
         GLib.timeout_add_seconds(2, self.reload_services)
 
+        self.status_icon = XApp.StatusIcon()
+        self.status_icon.set_name("mintupload")
+        self.status_icon.set_icon_name(SYSTRAY_ICON)
+        self.status_icon.set_tooltip_text(_("Upload services"))
+        self.status_icon.set_primary_menu(self.menu)
+        self.status_icon.set_secondary_menu(self.menu)
+
     def reload_services(self):
         has_changed = read_services() != self.services
 
@@ -74,13 +76,12 @@ class MainClass:
         menu_item.connect('activate', self.quit_cb)
         self.menu.append(menu_item)
         self.menu.show_all()
-        self.status_icon.set_menu(self.menu)
 
     def launch_manager(self, widget):
         os.system("/usr/lib/linuxmint/mintupload/upload-manager.py &")
 
     def create_drop_zone(self, widget, service):
-        if service['name'] not in self.drop_zones.keys():
+        if service['name'] not in list(self.drop_zones.keys()):
             drop_zone = DropZone(service, self.drop_zones)
             self.drop_zones[service['name']] = drop_zone
         else:
@@ -149,15 +150,14 @@ class DropZone:
         return True
 
     def drop_data_received_cb(self, widget, context, x, y, selection, targetType, time):
-        data = selection.get_data()
-
+        data = selection.get_data().decode()
         filenames = []
         files = data.split('\n')
 
         for f in files:
             if not f:
                 continue
-            f = urllib.url2pathname(f)
+            f = urllib.request.url2pathname(f)
             f = f.strip('\r')
             f = f.replace("file://", "")
             f = f.replace("'", r"'\''")
